#!/usr/bin/env python
# -*- coding: utf-8 -*-

# ######################################################################
# maintainer: einfall & schomi (schomi@vuplus-support.org)
# This plugin is free software, you are allowed to
# modify it (if you keep the license),
# but you are not allowed to distribute/publish
# it without source code (this version and your modifications).
# This means you also have to distribute
# source code of your modifications.
# ######################################################################
# Modded by lululla 20240805 
from . import _

from Components.ActionMap import ActionMap
from Components.FileList import FileList
from Components.Label import Label
from Components.Sources.StaticText import StaticText
from Plugins.Plugin import PluginDescriptor
from Screens.ChannelSelection import service_types_tv
from Screens.Screen import Screen
from Tools.Directories import fileExists
from enigma import eServiceCenter, eServiceReference
import os

pname = _("PiconRemover")
pdesc = _("Removes picons which are not used in bouquets")
pversion = "0.1-r1"
pdate = "20240806"


class PiconRemoverScreen(Screen):
    skin = """
            <screen name="PiconRemover" title="PiconRemover" position="510,340" size="900,400">
            <widget name="piconpath" position="22,40" size="750,60" font="Regular;30" foregroundColor="#00ffffff" transparent="1" zPosition="1" halign="left" />
            <widget name="piconcount" position="22,125" size="750,60" font="Regular;30" foregroundColor="#00fff000" transparent="1" zPosition="1" halign="left" />
            <widget name="picondelete" position="24,205" size="750,60" font="Regular;30" foregroundColor="#00ff0000" transparent="1" zPosition="1" halign="left" />
            <widget name="key_red" position="13,335" size="250,35" transparent="1" halign="center" zPosition="2" font="Regular;28" />
            <widget name="key_green" position="324,335" size="250,35" transparent="1" halign="center" zPosition="2" font="Regular;28" />
            <widget name="key_yellow" position="602,335" size="250,35" transparent="1" halign="center" zPosition="2" font="Regular;28" />
            <eLabel backgroundColor="red" position="15,375" size="250,6" zPosition="10" />
            <eLabel backgroundColor="green" position="322,375" size="250,6" zPosition="10" />
            <eLabel backgroundColor="yellow" position="600,375" size="250,6" zPosition="10" />
            </screen>"""

    def __init__(self, session):
        self.session = session
        Screen.__init__(self, session)

        piconfolder = "/usr/share/enigma2/picon/"
        self.piconfolder = piconfolder

        self['piconpath'] = Label(_("Picon folder: ") + self.piconfolder)
        self['piconcount'] = Label(_("Reading ..."))
        self['picondelete'] = Label()
        self['key_red'] = Label(_("Cancel"))
        self['key_green'] = Label(_("Ok"))
        self['key_yellow'] = Label(_("Select Picon folder"))
        self["actions"] = ActionMap(["OkCancelActions", "ColorActions"],
                                    {
                                    "ok":       self.keyOK,
                                    "cancel":   self.keyCancel,
                                    "red":      self.keyCancel,
                                    "green":    self.keyOK,
                                    "yellow":   self.keyYellow
                                    }, -1)

        self.onLayoutFinish.append(self.getInfo)

    def getInfo(self):
        kanaliste = buildChannellist()
        self.rm_list = None
        self.rm_list = []
        print(self.piconfolder)
        self['piconpath'].setText(_("Picon folder: ") + self.piconfolder)
        if fileExists(self.piconfolder):
            piconsliste = lsPicons(self)
            for picon in piconsliste:
                if picon not in kanaliste:
                    self.rm_list.append((picon))

        count = len(self.rm_list)
        self['piconcount'].setText(_("%s Picons found which can be deleted.") % str(count))

    def keyOK(self):
        if len(self.rm_list) > 0:
            for file in self.rm_list:
                file = file.replace(':', '_')
                file = file[:-1] + '.png'
                file = self.piconfolder + file
                if fileExists(file):
                    os.remove(file)
            count = len(self.rm_list)
            self['picondelete'].setText(_("%s Picons deleted!") % str(count))

    def keyCancel(self):
        self.close()

    def keyYellow(self):
        start_dir = "/usr/share/enigma2/"
        self.session.openWithCallback(self.selectedMediaFile, PiconRemoverFolderScreen, start_dir)

    def selectedMediaFile(self, res):
        if res is not None:
            self.piconfolder = res
        self.getInfo()


class PiconRemoverFolderScreen(Screen):
    skin = """
        <screen position="center,center" size="900,400" title=" ">
            <widget name="media" position="23,6" size="700,50" valign="top" font="Regular;24" />
            <widget name="folderlist" position="15,35" zPosition="1" size="690,240" scrollbarMode="showOnDemand" itemHeight="40" />
            <widget render="Label" source="key_red" position="15,337" size="250,35" valign="center" halign="center" zPosition="2" font="Regular;28" foregroundColor="white" />
            <widget render="Label" source="key_green" position="320,337" size="250,35" valign="center" halign="center" zPosition="2" font="Regular;28" foregroundColor="white" />
            <eLabel backgroundColor="red" position="15,375" size="250,6" zPosition="10" />
            <eLabel backgroundColor="green" position="322,375" size="250,6" zPosition="10" />
        </screen>
        """

    def __init__(self, session, initDir, plugin_path=None):
        Screen.__init__(self, session)
        # self.skin_path = plugin_path
        self["folderlist"] = FileList(initDir, inhibitMounts=False, inhibitDirs=False, showMountpoints=False, showFiles=False)
        self["media"] = Label()
        self["actions"] = ActionMap(["WizardActions", "DirectionActions", "ColorActions", "EPGSelectActions"],
                                    {
                                    "back": self.cancel,
                                    "left": self.left,
                                    "right": self.right,
                                    "up": self.up,
                                    "down": self.down,
                                    "ok": self.ok,
                                    "green": self.green,
                                    "red": self.cancel
                                    }, -1)
        self.title = _("Choose Picon folder")
        try:
            self["title"] = StaticText(self.title)
        except:
            print('self["title"] was not found in skin')
        self["key_red"] = StaticText(_("Cancel"))
        self["key_green"] = StaticText(_("Ok"))

    def cancel(self):
        self.close(None)

    def green(self):
        directory = self["folderlist"].getSelection()[0]
        if (directory.endswith("/")):
            self.fullpath = self["folderlist"].getSelection()[0]
        else:
            self.fullpath = self["folderlist"].getSelection()[0] + "/"
        self.close(self.fullpath)

    def up(self):
        self["folderlist"].up()
        self.updateFile()

    def down(self):
        self["folderlist"].down()
        self.updateFile()

    def left(self):
        self["folderlist"].pageUp()
        self.updateFile()

    def right(self):
        self["folderlist"].pageDown()
        self.updateFile()

    def ok(self):
        if self["folderlist"].canDescent():
            self["folderlist"].descent()
            self.updateFile()

    def updateFile(self):
        currFolder = self["folderlist"].getSelection()[0]
        self["media"].setText(currFolder)


def lsPicons(self):
    rm_plist = None
    rm_plist = []
    if fileExists(self.piconfolder):
        for dirname, dirnames, filenames in os.walk(self.piconfolder):
            for filename in filenames:
                if filename.lower().endswith('.png'):
                    # print filename.replace('.png',':').replace('_',':')
                    rm_plist.append((filename.replace('.png', ':').replace('_', ':')))
        return rm_plist


def getServiceList(ref):
    root = eServiceReference(str(ref))
    serviceHandler = eServiceCenter.getInstance()
    return serviceHandler.list(root).getContent("SN", True)


def getTVBouquets():
    return getServiceList(service_types_tv + ' FROM BOUQUET "bouquets.tv" ORDER BY bouquet')


def buildChannellist():
    rm_chlist = None
    rm_chlist = []
    tvbouquets = getTVBouquets()
    print("[RemovePicons] found %s bouquet: %s" % (len(tvbouquets), tvbouquets))

    for bouquet in tvbouquets:
        bouquetlist = []
        bouquetlist = getServiceList(bouquet[0])
        for (serviceref, servicename) in bouquetlist:
            # print servicename, serviceref
            rm_chlist.append((serviceref))
    return rm_chlist


def main(session, **kwargs):
    session.open(PiconRemoverScreen)


def Plugins(**kwargs):
    return PluginDescriptor(name=pname, description=pdesc, where=PluginDescriptor.WHERE_PLUGINMENU, icon="plugin.png", fnc=main)
